% Baseline ROT model estimated under determinacy
% Sample: 1955Q4-1979Q2


%----------------------------------------------------------------
% 0. Housekeeping
%----------------------------------------------------------------

close all;

%----------------------------------------------------------------
% 1. Defining variables
%----------------------------------------------------------------

var c_o_t c_t R_t i_t Q_o_t r_k_t u_t k_t c_rt_t w_t h_t g_t pi_t y_t mc_t lambda_p_t lambda_w_t mrs_o_t mrs_rt_t e_pma e_wma
gy_t gc_t gi_t gw_t eps_b_t eps_i_t eps_r_t eps_a_t gy_obs gc_obs gi_obs h_obs gw_obs pi_obs R_obs
c_o_t_f c_t_f R_t_f i_t_f Q_o_t_f r_k_t_f u_t_f k_t_f c_rt_t_f w_t_f h_t_f y_t_f mrs_o_t_f mrs_rt_t_f c_gap_t y_gap_t y_o_t y_rt_t gc_o_t gc_rt_t ineq_t;

varexo e_b e_i e_r e_p e_w e_a e_g;

parameters phiPI phiY phiGY phiR phi_l b gamI ksi_p ksi_w chi_p chi_w sigma_u theta rho_b rho_i rho_r rho_p rho_w rho_g rho_a Hss pss100 gzstar
beta sigma delta alpha alpha_p lambda_p g_y crt_co cmap cmaw rho_gy;

%fixed parameters

beta       = 0.9975;        % discount factor
delta      = 0.025;         % depreciation rate
alpha_p    = 6;             % goods elasticity of demand
lambda_p   = 0.2;           % steady state net price markup
g_y        = 0.2;           % gov spending to GDP ration
crt_co     = 1;             % steady state consumption ratio between two groups


%----------------------------------------------------------------
% 3. Model
%----------------------------------------------------------------

model(linear);

#gz         = 1+(gzstar/100); 
#rss        = gz/beta-1;
#rss100     = rss*100;

#rk = (gz/beta)+delta-1;
#i_k = 1 - ((1-delta)/gz);
#w = ((1/(1+lambda_p))*(((alpha^(alpha))*((1-alpha)^(1-alpha)))/(rk^alpha)))^(1/(1-alpha));
#h_k = (1/gz)*((1-alpha)/alpha)*(rk/w);
#k_y = (1+lambda_p)*(gz^alpha)*(h_k^(alpha-1));
#i_y = i_k*k_y;
#c_y = 1-i_y-g_y;
#wh_c = (1-alpha)*(1/c_y);
#c_rt = ((1/(1-theta))*crt_co)/(1+(theta/(1-theta))*crt_co);
#c_o = (1/(1-theta)) - (theta/(1-theta))*c_rt;
#omega = (theta/(1-theta))*(((c_rt-b)/(c_o-b))^(-sigma));
#A = 1/(lambda_p*alpha_p+1);
#wh_y = 1-alpha;



c_o_t = c_o_t(+1) + (((1-b*(1/c_o))*b)/(c_o-b))*(c_t(-1) - c_t) - ((1-b*(1/c_o))/sigma)*(R_t - pi_t(+1)) - eps_b_t;
i_t = (1/(gamI*(gz^2)*(1+beta)))*Q_o_t + (1/(1+beta))*i_t(-1) + (beta/(1+beta))*i_t(+1) + eps_i_t;
-R_t - (sigma/(1-b*(1/c_o)))*eps_b_t + pi_t(+1) + (beta/gz)*rk*r_k_t(+1) + (beta/gz)*(1-delta)*Q_o_t(+1) = Q_o_t;
r_k_t = (sigma_u/(1-sigma_u))*u_t;
k_t = ((1-delta)/gz)*k_t(-1) + i_k*i_t + i_k*gamI*(gz^2)*(1+beta)*eps_i_t;
c_rt*c_rt_t = wh_c*(w_t + h_t);
c_y*c_t + g_t + i_y*i_t - y_t + ((rk/gz)*k_y)*u_t = 0;
c_t = theta*c_rt*c_rt_t + (1-theta)*c_o*c_o_t;
(1+beta*chi_p)*pi_t = chi_p*pi_t(-1) + beta*pi_t(+1) + A*(((1-beta*ksi_p)*(1-ksi_p))/ksi_p)*mc_t + lambda_p_t;
w_t = -(((1-ksi_w)*(1-ksi_w*beta))/((1+beta)*ksi_w))*(w_t - (1/(1+omega))*(mrs_o_t + omega*mrs_rt_t)) + (beta/(1+beta))*w_t(+1) + (1/(1+beta))*w_t(-1) + (chi_w/(1+beta))*pi_t(-1) - ((1+beta*chi_w)/(1+beta))*pi_t + (beta/(1+beta))*pi_t(+1) + lambda_w_t;
mrs_o_t = (sigma/(1-b*(1/c_o)))*c_o_t - ((b*sigma)/(c_o-b))*c_t(-1) + phi_l*h_t; 
mrs_rt_t = (sigma/(1-b*(1/c_rt)))*c_rt_t - ((b*sigma)/(c_rt-b))*c_t(-1) + phi_l*h_t;
u_t + k_t(-1) - h_t = w_t - r_k_t;
mc_t = -eps_a_t + alpha*r_k_t + (1-alpha)*w_t;
y_t = (1+lambda_p)*(eps_a_t+alpha*(k_t(-1) + u_t) + (1-alpha)*h_t);
R_t = phiR*R_t(-1) + (1-phiR)*(phiPI*pi_t + phiY*(y_t-y_t_f)) + phiGY*((y_t-y_t(-1)) - (y_t_f-y_t_f(-1))) + eps_r_t;
gy_t = y_t - y_t(-1);
gc_t = c_t - c_t(-1);
gi_t = i_t - i_t(-1);
gw_t = w_t - w_t(-1);
eps_a_t = rho_a*eps_a_t(-1) + e_a;
eps_b_t = rho_b*eps_b_t(-1) + e_b;
eps_i_t = rho_i*eps_i_t(-1) + e_i;
eps_r_t = rho_r*eps_r_t(-1) + e_r;
g_t = rho_g*(g_t(-1)) + e_g + rho_gy*e_a;
lambda_p_t = rho_p*lambda_p_t(-1) + e_pma - cmap*e_pma(-1);
e_pma = e_p;
lambda_w_t = rho_w*lambda_w_t(-1) + e_wma - cmaw*e_wma(-1);
e_wma = e_w;

% Flexible price equilibrium

c_o_t_f = c_o_t_f(+1) + (((1-b*(1/c_o))*b)/(c_o-b))*(c_t_f(-1) - c_t_f) - ((1-b*(1/c_o))/sigma)*(R_t_f) - eps_b_t;
i_t_f = (1/(gamI*(gz^2)*(1+beta)))*Q_o_t_f + (1/(1+beta))*i_t_f(-1) + (beta/(1+beta))*i_t_f(+1) + eps_i_t;
-R_t_f - (sigma/(1-b*(1/c_o)))*eps_b_t + (beta/gz)*rk*r_k_t_f(+1) + (beta/gz)*(1-delta)*Q_o_t_f(+1) = Q_o_t_f;
r_k_t_f = (sigma_u/(1-sigma_u))*u_t_f;
k_t_f = ((1-delta)/gz)*k_t_f(-1) + i_k*i_t_f + i_k*gamI*(gz^2)*(1+beta)*eps_i_t;
c_rt*c_rt_t_f = wh_c*(w_t_f + h_t_f);
c_y*c_t_f + g_t + i_y*i_t_f - y_t_f + ((rk/gz)*k_y)*u_t_f = 0;
c_t_f = theta*c_rt*c_rt_t_f + (1-theta)*c_o*c_o_t_f;
w_t_f = (1/(1+omega))*(mrs_o_t_f + omega*mrs_rt_t_f);
mrs_o_t_f = (sigma/(1-b*(1/c_o)))*c_o_t_f - ((b*sigma)/(c_o-b))*c_t_f(-1) + phi_l*h_t_f; 
mrs_rt_t_f = (sigma/(1-b*(1/c_rt)))*c_rt_t_f - ((b*sigma)/(c_rt-b))*c_t_f(-1) + phi_l*h_t_f;
u_t_f + k_t_f(-1) - h_t_f = w_t_f - r_k_t_f;
0 = -eps_a_t + alpha*r_k_t_f + (1-alpha)*w_t_f;
y_t_f = (1+lambda_p)*(eps_a_t+alpha*(k_t_f(-1) + u_t_f) + (1-alpha)*h_t_f);

gc_o_t = c_o_t - c_o_t(-1);
gc_rt_t = c_rt_t - c_rt_t(-1);

% Consumption and Output Gap
c_gap_t = c_rt_t-c_o_t;
y_gap_t = y_t-y_t_f;


% ROT and Ricardian consumers' income
y_rt_t = w_t + h_t;
y_o_t = (1/(1-theta*wh_y))*y_t - (theta*wh_y/(1-theta*wh_y))*w_t - (theta*wh_y/(1-theta*wh_y))*h_t - (((rk/gz)*k_y)/(1-theta*wh_y))*u_t;

% Income inequality
ineq_t = y_o_t-y_rt_t;

% Observation equations:

gy_obs = gzstar + gy_t;
gc_obs = gzstar + gc_t;
gi_obs = gzstar + gi_t;
h_obs  = Hss + h_t;
gw_obs = gzstar + gw_t;
pi_obs = pss100 + pi_t;
R_obs  = pss100 + rss100 + R_t;
 

end;

estimated_params;

phiPI, 1.1 ,0.01 , , normal_pdf, 1.0, 0.35;
phiY, 0.13 , 0.01, , normal_pdf, 0.12, 0.05;
phiGY, 0.13 , 0.01, , normal_pdf, 0.12, 0.05;
phiR, 0.6 , , , beta_pdf, 0.75, 0.1;
phi_l,2 , , ,gamma_pdf,2.0,0.75;
b, 0.5 , , , beta_pdf, 0.7, 0.1;
gamI,4 , , ,gamma_pdf,4.0,1.50;
ksi_p, 0.66 , , , beta_pdf, 0.5, 0.1;
ksi_w, 0.66 , , , beta_pdf, 0.5, 0.1;
chi_p, 0.5 , , , beta_pdf, 0.5, 0.15;
chi_w, 0.5 , , , beta_pdf, 0.5, 0.15;
sigma_u, 0.5 , , , beta_pdf, 0.5, 0.15;
theta, 0.3 , , , beta_pdf, 0.3, 0.1;
sigma, 1 , 0.01, , normal_pdf, 1.5, 0.37;
alpha, 0.3 , 0.01, 1, normal_pdf, 0.3, 0.05;
gzstar, 0.4 , 0.01, , normal_pdf, 0.4, 0.1;
Hss, 0.0 , , , normal_pdf, 0, 2;
pss100, 1 , 0.01, , gamma_pdf, 0.62, 0.1;

stderr e_b,0.1 , , , inv_gamma_pdf, 0.10, 2.00;
stderr e_i, 0.1, , , inv_gamma_pdf, 0.10, 2.00;
stderr e_r, 0.1, , , inv_gamma_pdf, 0.10, 2.00;
stderr e_p,0.1 , , , inv_gamma_pdf, 0.10, 2.00;
stderr e_w,0.1, , , inv_gamma_pdf, 0.10, 2.00;
stderr e_g, 0.5, , , inv_gamma_pdf, 0.10, 2.00;
stderr e_a, 0.5, , , inv_gamma_pdf,0.10, 2.00;
rho_b, 0.6 , , , beta_pdf, 0.5, 0.2;
rho_i, 0.6 , , , beta_pdf, 0.5, 0.2;
rho_r, 0.6 , , , beta_pdf, 0.5, 0.2;
rho_p, 0.6 , , , beta_pdf, 0.5, 0.2;
rho_w, 0.6 , , , beta_pdf, 0.5, 0.2;
rho_g, 0.6 , , , beta_pdf, 0.5, 0.2;
rho_a, 0.6 , , , beta_pdf, 0.5, 0.2;
cmap, .7652, , , beta_pdf, 0.5, 0.2;
cmaw, .5, , , beta_pdf, 0.5, 0.2;
rho_gy, 0.05, 0.01, , normal_pdf, 0.5, 0.25;



end;


varobs gy_obs gc_obs gi_obs h_obs gw_obs pi_obs R_obs;

estimation(datafile=data_1955Q4to1979Q2, mh_replic=500000, mh_drop = 0.2, mh_jscale=0.32, mh_nblocks=1, mode_file=ROT_AAH_det_mode, mode_compute=0);


