function [T1,T0,TETA,AMU_,ne,m,RC]=sims_solve(A0,A1,B,C,div)
%
% First we compute the Schur decomposition A0=Q'*T*Z' and A1=Q'*S*Z'
%
RC = [0;0];
tol_=1e-6;
[T S Q Z]	= qz(A0,A1);
[T S Q Z]   = qzdiv(div,T,S,Q,Z);
n           = size(A0,1);   % number of variables
nf          = size(B,2);    % number of fundamental shocks
ne          = size(C,2);    % number of expectation errors
%
% We recover the diagonal of the S and T matrix in order to 
%
%	1) Determine the status of variables
%	2) compute the generalized eigenvalues
%
DS_			= diag(S);
DT_			= diag(T);
%
% Dynamic variables 
%
%dyn_		= find(abs(DT_)>tol_);	    % Determine dynamic variables
MU_			= DS_./DT_;		% Compute generalized eigenvalues
AMU_		= abs(MU_);				    % Compute their modulus
m			= sum(AMU_>div);			% Find the forward variables
Q1          = Q(1:n-m,:);
Q2          = Q(n-m+1:n,:);
Z1          = Z(:,1:n-m)';
Z2          = Z(:,n-m+1:n)';

[U1,D1,V1]  = svd(Q2*C);
r           = rank(Q2*C);               % number of linearly independent forecast errors

T11         = T(1:n-m,1:n-m);
T12         = T(1:n-m,n-m+1:n);
T22         = T(n-m+1:n,n-m+1:n);

T1i         = inv(T11);
S11         = S(1:n-m,1:n-m);
S12         = S(1:n-m,n-m+1:n);
S22         = S(n-m+1:n,n-m+1:n);

[U1,D1,V1]   = svd(Q1*C);
r1           = rank(Q1*C);
[U2,D2,V2]   = svd(Q2*C);
r2           = rank(Q2*C);

Phi         = ((U2(:,1:r2)*(D2(1:r2,1:r2)\V2(:,1:r2)'))*(V1(:,1:r1)*D1(1:r1,1:r1)*U1(:,1:r1)'))';


if ne==r2
    RC = [1;1];
elseif ne>r2
    RC = [1;0];
else 
    RC =[-2;-2];
end

Transfo     = [eye(n-m) -Phi];
MY0         = inv([Transfo*T;zeros(m,n-m) eye(m)]);
MY1         = ([Transfo*S;zeros(m,n)]);
T1          = Z*(MY0*MY1)*Z';
   

T0 = MY0*[Transfo*Q*B; zeros(m,size(B,2))];
TETA = MY0*[(Q1*C - Q1*C*V2(:,1:r2)*V2(:,1:r2)')*V2(:,r2+1:ne); zeros(m,size(V2(:,r2+1:ne),2))];

T1  = real(T1);
T0  = real(Z*T0);
TETA  = real(Z*TETA);