%==========================================================================
% Code for generating the IRFs in the manuscript
%==========================================================================

%=========================================================================
%                              HOUSEKEEPING
%=========================================================================

close all
clear
clc
delete *.asv


disp('                                                                  ');
disp(' IMPULSE RESPONSE FUNCTIONS: ROT vs RANK: 1955Q4-1979Q2: INDETERMINACY   ');
disp('                                                                  ');

%=========================================================================
%              LOAD POSTERIOR DRAWS AND COMPUTE IRFS
%=========================================================================



Nirf        = 20; % Number of Quarters for IRFs

nend        = 54;  % Number of Endogenous Variables

IRF_ROT_IND_technology        = zeros(nend,Nirf);
IRF_ROT_IND_riskpremium       = zeros(nend,Nirf);
IRF_ROT_IND_investment        = zeros(nend,Nirf);
IRF_ROT_IND_policy            = zeros(nend,Nirf);
IRF_ROT_IND_pricemarkup       = zeros(nend,Nirf);
IRF_ROT_IND_wagemarkup        = zeros(nend,Nirf);
IRF_ROT_IND_government        = zeros(nend,Nirf);


IRF_RANK_IND_technology        = zeros(nend,Nirf);
IRF_RANK_IND_riskpremium       = zeros(nend,Nirf);
IRF_RANK_IND_investment        = zeros(nend,Nirf);
IRF_RANK_IND_policy            = zeros(nend,Nirf);
IRF_RANK_IND_pricemarkup       = zeros(nend,Nirf);
IRF_RANK_IND_wagemarkup        = zeros(nend,Nirf);
IRF_RANK_IND_government        = zeros(nend,Nirf);
IRF_RANK_IND_sunspot           = zeros(nend,Nirf);


%% IRF with estimated model parameters set at the posterior mean, sample period 1955Q4-1979Q2, ROT model under Indeterminacy

load ROT_IND_55-79_mean    % Load posterior mean estimates
% 
% 
para = xparam1;


[MY,ME,ETA,AMU_,ne,r2,RC] = model_solution_rot_ind(para);

[A,B,H,R,Se,Phi,n] = sysmat_rot_ind(MY,ME,para);

L = chol(Se,'lower');
R = R*L;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % TECHNOLOGY SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(1,1)       = 1;

IRF_ROT_IND_technology(:,1) = R*e;

for m=2:Nirf
    
    IRF_ROT_IND_technology(:,m) = Phi*IRF_ROT_IND_technology(:,m-1);
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % RISK PREMIUM SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(2,1)       = 1;

IRF_ROT_IND_riskpremium(:,1) = R*e;

for m=2:Nirf
    
    IRF_ROT_IND_riskpremium(:,m) = Phi*IRF_ROT_IND_riskpremium(:,m-1);
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % INVESTMENT SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(3,1)       = 1;

IRF_ROT_IND_investment(:,1) = R*e;

for m=2:Nirf
    
    IRF_ROT_IND_investment(:,m) = Phi*IRF_ROT_IND_investment(:,m-1);
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % MONETARY POLICY SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(4,1)       = 1;

IRF_ROT_IND_policy(:,1) = R*e;

for m=2:Nirf
    
    IRF_ROT_IND_policy(:,m) = Phi*IRF_ROT_IND_policy(:,m-1);
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % PRICE MARKUP SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(5,1)       = 1;

IRF_ROT_IND_pricemarkup(:,1) = R*e;

for m=2:Nirf
    
    IRF_ROT_IND_pricemarkup(:,m) = Phi*IRF_ROT_IND_pricemarkup(:,m-1);
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % WAGE MARKUP SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(6,1)       = 1;

IRF_ROT_IND_wagemarkup(:,1) = R*e;

for m=2:Nirf
    
    IRF_ROT_IND_wagemarkup(:,m) = Phi*IRF_ROT_IND_wagemarkup(:,m-1);
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % GOVERNMENT SPENDING SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(7,1)       = 1;

IRF_ROT_IND_government(:,1) = R*e;

for m=2:Nirf
    
    IRF_ROT_IND_government(:,m) = Phi*IRF_ROT_IND_government(:,m-1);
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % SUNSPOT SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(8,1)       = 1;

IRF_ROT_IND_sunspot(:,1) = R*e;

for m=2:Nirf
    
    IRF_ROT_IND_sunspot(:,m) = Phi*IRF_ROT_IND_sunspot(:,m-1);
    
end





%% IRF with estimated model parameters set at the posterior mean, sample period 1955Q4-1979Q2, RANK model under Indeterminacy

load RANK_IND_55-79_mean    % Load posterior mean estimates
% 
% 
para = xparam1;


[MY,ME,ETA,AMU_,ne,r2,RC] = model_solution_rank_ind(para);

[A,B,H,R,Se,Phi,n] = sysmat_rank_ind(MY,ME,para);

L = chol(Se,'lower');
R = R*L;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % TECHNOLOGY SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(1,1)       = 1;

IRF_RANK_IND_technology(:,1) = R*e;

for m=2:Nirf
    
    IRF_RANK_IND_technology(:,m) = Phi*IRF_RANK_IND_technology(:,m-1);
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % RISK PREMIUM SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(2,1)       = 1;

IRF_RANK_IND_riskpremium(:,1) = R*e;

for m=2:Nirf
    
    IRF_RANK_IND_riskpremium(:,m) = Phi*IRF_RANK_IND_riskpremium(:,m-1);
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % INVESTMENT SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(3,1)       = 1;

IRF_RANK_IND_investment(:,1) = R*e;

for m=2:Nirf
    
    IRF_RANK_IND_investment(:,m) = Phi*IRF_RANK_IND_investment(:,m-1);
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % MONETARY POLICY SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(4,1)       = 1;

IRF_RANK_IND_policy(:,1) = R*e;

for m=2:Nirf
    
    IRF_RANK_IND_policy(:,m) = Phi*IRF_RANK_IND_policy(:,m-1);
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % PRICE MARKUP SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(5,1)       = 1;

IRF_RANK_IND_pricemarkup(:,1) = R*e;

for m=2:Nirf
    
    IRF_RANK_IND_pricemarkup(:,m) = Phi*IRF_RANK_IND_pricemarkup(:,m-1);
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % WAGE MARKUP SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(6,1)       = 1;

IRF_RANK_IND_wagemarkup(:,1) = R*e;

for m=2:Nirf
    
    IRF_RANK_IND_wagemarkup(:,m) = Phi*IRF_RANK_IND_wagemarkup(:,m-1);
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % GOVERNMENT SPENDING SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(7,1)       = 1;

IRF_RANK_IND_government(:,1) = R*e;

for m=2:Nirf
    
    IRF_RANK_IND_government(:,m) = Phi*IRF_RANK_IND_government(:,m-1);
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % SUNSPOT SHOCK
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

e            = zeros(8,1);

e(8,1)       = 1;

IRF_RANK_IND_sunspot(:,1) = R*e;

for m=2:Nirf
    
    IRF_RANK_IND_sunspot(:,m) = Phi*IRF_RANK_IND_sunspot(:,m-1);
    
end





%%
%=========================================================================
%                  PLOT IRFS 
%=========================================================================



pnames = strvcat('output','hours', 'investment', 'aggr consumption', 'ROT consumption', 'Ricardian consumption', 'real wage', 'inflation', 'nom interest rate');


%% IRF to technology shocks

t = 0:19;    

figure('Position',[20,20,900,600],'Color','w')
    
    
    subplot(3,3,1), plot(t,IRF_ROT_IND_technology(14,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_technology(14,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(1,:),'FontSize',12,'FontWeight','bold');
    box on   
    
    subplot(3,3,2), plot(t,IRF_ROT_IND_technology(11,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_technology(11,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(2,:),'FontSize',12,'FontWeight','bold');
    box on   
    
    subplot(3,3,3), plot(t,IRF_ROT_IND_technology(4,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_technology(4,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(3,:),'FontSize',12,'FontWeight','bold');
    box on  
    
    subplot(3,3,4), plot(t,IRF_ROT_IND_technology(2,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_technology(2,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(4,:),'FontSize',12,'FontWeight','bold');
    box on   
    
    subplot(3,3,5), plot(t,IRF_ROT_IND_technology(9,:),'k','LineWidth',1), hold on
    set(gca,'FontSize',18);
    title(pnames(5,:),'FontSize',12,'FontWeight','bold');
    box on   
    
    subplot(3,3,6), plot(t,IRF_ROT_IND_technology(1,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_technology(1,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(6,:),'FontSize',12,'FontWeight','bold');
    box on   
    
    subplot(3,3,7), plot(t,IRF_ROT_IND_technology(10,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_technology(10,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(7,:),'FontSize',12,'FontWeight','bold');
    box on   
    
    subplot(3,3,8), plot(t,IRF_ROT_IND_technology(13,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_technology(13,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(8,:),'FontSize',12,'FontWeight','bold');
    box on  
    
    subplot(3,3,9), plot(t,IRF_ROT_IND_technology(3,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_technology(3,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    legend('ROT-IND','RANK-IND');
    title(pnames(9,:),'FontSize',12,'FontWeight','bold');
    box on 

print(gcf,'IRF_technologyshock.eps','-deps','-r600');



%% IRF to risk premium shocks

t = 0:19;    

figure('Position',[20,20,900,600],'Color','w')
    
    
    subplot(3,3,1), plot(t,IRF_ROT_IND_riskpremium(14,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_riskpremium(14,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(1,:),'FontSize',12,'FontWeight','bold');
    box on  
    
    subplot(3,3,2), plot(t,IRF_ROT_IND_riskpremium(11,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_riskpremium(11,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(2,:),'FontSize',12,'FontWeight','bold');
    box on   
    
    subplot(3,3,3), plot(t,IRF_ROT_IND_riskpremium(4,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_riskpremium(4,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(3,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,4), plot(t,IRF_ROT_IND_riskpremium(2,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_riskpremium(2,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(4,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,5), plot(t,IRF_ROT_IND_riskpremium(9,:),'k','LineWidth',1), hold on
    set(gca,'FontSize',18);
    title(pnames(5,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,6), plot(t,IRF_ROT_IND_riskpremium(1,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_riskpremium(1,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(6,:),'FontSize',12,'FontWeight','bold');
    box on  
    
    subplot(3,3,7), plot(t,IRF_ROT_IND_riskpremium(10,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_riskpremium(10,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(7,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,8), plot(t,IRF_ROT_IND_riskpremium(13,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_riskpremium(13,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(8,:),'FontSize',12,'FontWeight','bold');
    box on   
    
    subplot(3,3,9), plot(t,IRF_ROT_IND_riskpremium(3,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_riskpremium(3,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    legend('ROT-IND','RANK-IND');
    title(pnames(9,:),'FontSize',12,'FontWeight','bold');
    box on 
   

print(gcf,'IRF_riskpremiumshock.eps','-deps','-r600');


%% IRF to investment shocks

t = 0:19;    

figure('Position',[20,20,900,600],'Color','w')
    
    
    subplot(3,3,1), plot(t,IRF_ROT_IND_investment(14,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_investment(14,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(1,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,2), plot(t,IRF_ROT_IND_investment(11,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_investment(11,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(2,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,3), plot(t,IRF_ROT_IND_investment(4,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_investment(4,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(3,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,4), plot(t,IRF_ROT_IND_investment(2,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_investment(2,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(4,:),'FontSize',12,'FontWeight','bold');
    box on  
    
    subplot(3,3,5), plot(t,IRF_ROT_IND_investment(9,:),'k','LineWidth',1), hold on
    set(gca,'FontSize',18);
    title(pnames(5,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,6), plot(t,IRF_ROT_IND_investment(1,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_investment(1,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(6,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,7), plot(t,IRF_ROT_IND_investment(10,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_investment(10,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(7,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,8), plot(t,IRF_ROT_IND_investment(13,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_investment(13,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(8,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,9), plot(t,IRF_ROT_IND_investment(3,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_investment(3,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    legend('ROT-IND','RANK-IND');
    title(pnames(9,:),'FontSize',12,'FontWeight','bold');
    box on 
   

print(gcf,'IRF_investmentshock.eps','-deps','-r600');


%% IRF to monetary policy shocks

t = 0:19;    

figure('Position',[20,20,900,600],'Color','w')
    
    
    subplot(3,3,1), plot(t,IRF_ROT_IND_policy(14,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_policy(14,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(1,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,2), plot(t,IRF_ROT_IND_policy(11,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_policy(11,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(2,:),'FontSize',12,'FontWeight','bold');
    box on  
    
    subplot(3,3,3), plot(t,IRF_ROT_IND_policy(4,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_policy(4,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(3,:),'FontSize',12,'FontWeight','bold');
    box on  
    
    subplot(3,3,4), plot(t,IRF_ROT_IND_policy(2,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_policy(2,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(4,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,5), plot(t,IRF_ROT_IND_policy(9,:),'k','LineWidth',1), hold on
    set(gca,'FontSize',18);
    title(pnames(5,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,6), plot(t,IRF_ROT_IND_policy(1,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_policy(1,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(6,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,7), plot(t,IRF_ROT_IND_policy(10,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_policy(10,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(7,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,8), plot(t,IRF_ROT_IND_policy(13,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_policy(13,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(8,:),'FontSize',12,'FontWeight','bold');
    box on   
    
    subplot(3,3,9), plot(t,IRF_ROT_IND_policy(3,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_policy(3,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    legend('ROT-IND','RANK-IND');
    title(pnames(9,:),'FontSize',12,'FontWeight','bold');
    box on   
   

print(gcf,'IRF_policyshock.eps','-deps','-r600');



%% IRF to price markup shocks

t = 0:19;    

figure('Position',[20,20,900,600],'Color','w')
    
    
    subplot(3,3,1), plot(t,IRF_ROT_IND_pricemarkup(14,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_pricemarkup(14,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(1,:),'FontSize',12,'FontWeight','bold');
    box on  
    
    subplot(3,3,2), plot(t,IRF_ROT_IND_pricemarkup(11,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_pricemarkup(11,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(2,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,3), plot(t,IRF_ROT_IND_pricemarkup(4,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_pricemarkup(4,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(3,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,4), plot(t,IRF_ROT_IND_pricemarkup(2,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_pricemarkup(2,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(4,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,5), plot(t,IRF_ROT_IND_pricemarkup(9,:),'k','LineWidth',1), hold on
    set(gca,'FontSize',18);
    title(pnames(5,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,6), plot(t,IRF_ROT_IND_pricemarkup(1,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_pricemarkup(1,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(6,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,7), plot(t,IRF_ROT_IND_pricemarkup(10,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_pricemarkup(10,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(7,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,8), plot(t,IRF_ROT_IND_pricemarkup(13,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_pricemarkup(13,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(8,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,9), plot(t,IRF_ROT_IND_pricemarkup(3,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_pricemarkup(3,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    legend('ROT-IND','RANK-IND');
    title(pnames(9,:),'FontSize',12,'FontWeight','bold');
    box on 


print(gcf,'IRF_pricemarkupshock.eps','-deps','-r600');


%% IRF to wage markup shocks

t = 0:19;    

figure('Position',[20,20,900,600],'Color','w')
    
    
    subplot(3,3,1), plot(t,IRF_ROT_IND_wagemarkup(14,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_wagemarkup(14,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(1,:),'FontSize',12,'FontWeight','bold');
    box on  
    
    subplot(3,3,2), plot(t,IRF_ROT_IND_wagemarkup(11,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_wagemarkup(11,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(2,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,3), plot(t,IRF_ROT_IND_wagemarkup(4,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_wagemarkup(4,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(3,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,4), plot(t,IRF_ROT_IND_wagemarkup(2,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_wagemarkup(2,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(4,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,5), plot(t,IRF_ROT_IND_wagemarkup(9,:),'k','LineWidth',1), hold on
    set(gca,'FontSize',18);
    title(pnames(5,:),'FontSize',12,'FontWeight','bold');
    box on  
    
    subplot(3,3,6), plot(t,IRF_ROT_IND_wagemarkup(1,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_wagemarkup(1,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(6,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,7), plot(t,IRF_ROT_IND_wagemarkup(10,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_wagemarkup(10,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(7,:),'FontSize',12,'FontWeight','bold');
    box on  
    
    subplot(3,3,8), plot(t,IRF_ROT_IND_wagemarkup(13,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_wagemarkup(13,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(8,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,9), plot(t,IRF_ROT_IND_wagemarkup(3,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_wagemarkup(3,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    legend('ROT-IND','RANK-IND');
    title(pnames(9,:),'FontSize',12,'FontWeight','bold');
    box on 
   
    
print(gcf,'IRF_wagemarkupshock.eps','-deps','-r600');


%% IRF to government spending shock

t = 0:19;    

figure('Position',[20,20,900,600],'Color','w')
    
    
    subplot(3,3,1), plot(t,IRF_ROT_IND_government(14,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_government(14,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(1,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,2), plot(t,IRF_ROT_IND_government(11,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_government(11,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(2,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,3), plot(t,IRF_ROT_IND_government(4,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_government(4,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(3,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,4), plot(t,IRF_ROT_IND_government(2,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_government(2,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(4,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,5), plot(t,IRF_ROT_IND_government(9,:),'k','LineWidth',1), hold on
    set(gca,'FontSize',18);
    title(pnames(5,:),'FontSize',12,'FontWeight','bold');
    box on  
    
    subplot(3,3,6), plot(t,IRF_ROT_IND_government(1,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_government(1,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(6,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,7), plot(t,IRF_ROT_IND_government(10,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_government(10,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(7,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,8), plot(t,IRF_ROT_IND_government(13,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_government(13,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(8,:),'FontSize',12,'FontWeight','bold');
    box on   
    
    subplot(3,3,9), plot(t,IRF_ROT_IND_government(3,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_government(3,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    legend('ROT-IND','RANK-IND');
    title(pnames(9,:),'FontSize',12,'FontWeight','bold');
    box on    


print(gcf,'IRF_government.eps','-deps','-r600');

%% IRF to sunspot shock

t = 0:19;    

figure('Position',[20,20,900,600],'Color','w')
    
    
    subplot(3,3,1), plot(t,IRF_ROT_IND_sunspot(14,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_sunspot(14,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(1,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,2), plot(t,IRF_ROT_IND_sunspot(11,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_sunspot(11,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(2,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,3), plot(t,IRF_ROT_IND_sunspot(4,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_sunspot(4,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(3,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,4), plot(t,IRF_ROT_IND_sunspot(2,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_sunspot(2,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(4,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,5), plot(t,IRF_ROT_IND_sunspot(9,:),'k','LineWidth',1), hold on
    set(gca,'FontSize',18);
    title(pnames(5,:),'FontSize',12,'FontWeight','bold');
    box on  
    
    subplot(3,3,6), plot(t,IRF_ROT_IND_sunspot(1,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_sunspot(1,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(6,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,7), plot(t,IRF_ROT_IND_sunspot(10,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_sunspot(10,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(7,:),'FontSize',12,'FontWeight','bold');
    box on 
    
    subplot(3,3,8), plot(t,IRF_ROT_IND_sunspot(13,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_sunspot(13,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    title(pnames(8,:),'FontSize',12,'FontWeight','bold');
    box on   
    
    subplot(3,3,9), plot(t,IRF_ROT_IND_sunspot(3,:),'k','LineWidth',1), hold on
    plot(t,IRF_RANK_IND_sunspot(3,:),'k:','LineWidth',1)
    set(gca,'FontSize',18);
    legend('ROT-IND','RANK-IND');
    title(pnames(9,:),'FontSize',12,'FontWeight','bold');
    box on    

print(gcf,'IRF_sunspot.eps','-deps','-r600');