function [A,B,H,R,Se,Phi,n] = sysmat_rot_ind(MY,ME,para)

% This function computes the matrices of the state space representation.
% Input = para : Vector of Structural Parameters
%         T1 T0: 
% Output= Matrices of state space model. See kalman.m

% -------------------------------------------------------------------------
% Parameters
% -------------------------------------------------------------------------

sig_b          = para(1);           % st dev of shocks
sig_i          = para(2);
sig_r          = para(3);
sig_p          = para(4);
sig_w          = para(5);
sig_g          = para(6);
sig_a          = para(7);
sig_v1         = para(8);
rho_pv1        = para(9);


phiPI   = para(10);        % response to inflation
phiY    = para(11);        % response to output
phiGY   = para(12);        % response to output growth
phiR    = para(13);        % TR smoothing
phi_l   = para(14);        % invserse Frish elasticity of labor supply
b       = para(15);        % habit
gamI    = para(16);        % investment adjust cost
ksi_p   = para(17);        % calvo price stickiness
ksi_w   = para(18);        % calvo wage stickiness
chi_p   = para(19);       % price indexation
chi_w   = para(20);       % wage indexation
sigma_u = para(21);       % elasticity of the capital utilization cost function
theta   = para(22);              % fraction of HTMC
sigma   = para(23);       % elasticity of inter-temporal substitution, sigma = 1 implies log utility
alpha   = para(24);       % share of capital in the prod. function
gzstar  = para(25);       % quarterly net growth rate in steady state
Hss     = para(26);          % steady state for log hours
pss100  = para(27);          % quarterly net growth rate of inflation

rho_b          = para(28);         % AR(1) coefficients of the shock processes
rho_i          = para(29);
rho_r          = para(30);
rho_lambda_p   = para(31);
rho_lambda_w   = para(32);
rho_g          = para(33);
rho_a          = para(34);
cmap           = para(35);
cmaw           = para(36);
rho_gy         = para(37);



beta       = 0.9975;           % discount factor
delta      = 0.025;            % depreciation rate
alpha_p    = 6;                % goods elasticity of demand
lambda_p   = 0.2;              % steady state net price markup
gz         = 1+(gzstar/100);   % quarterly gross growth rate in steady state
g_y        = 0.20;             % gov spending to GDP ration
crt_co     = 1;                % steady state consumption ratio between two groups
alpha1     = 1.5;              % AR(1) coefficient of the augmented equation ala Bianchi-Nicolo
rss        = gz/beta-1;
rss100     = rss*100;

% -------------------------------------------------------------------------
% steady state relationships
% -------------------------------------------------------------------------

rk = (gz/beta)+delta-1;
i_k = 1 - ((1-delta)/gz);
w = ((1/(1+lambda_p))*(((alpha^(alpha))*((1-alpha)^(1-alpha)))/(rk^alpha)))^(1/(1-alpha));
h_k = (1/gz)*((1-alpha)/alpha)*(rk/w);
k_y = (1+lambda_p)*(gz^alpha)*(h_k^(alpha-1));
i_y = i_k*k_y;
c_y = 1-i_y-g_y;
wh_c = (1-alpha)*(1/c_y);
c_rt = ((1/(1-theta))*crt_co)/(1+(theta/(1-theta))*crt_co);
c_o = (1/(1-theta)) - (theta/(1-theta))*c_rt;
omega = (theta/(1-theta))*(((c_rt-b)/(c_o-b))^(-sigma));
A = 1/(lambda_p*alpha_p+1);



eq_gy = 1;
eq_gc = 2;
eq_gi = 3;
eq_h = 4;
eq_gw = 5;
eq_pi = 6;
eq_R = 7;

% /** number of observation variables **/

ny = 7;

% /** model variable indices **/

c_o_t = 1;        % consumption of ricardian agents
c_t = 2;          % aggregate consumption
R_t = 3;          % Nominal interest rate
i_t = 4;          % Investment
Q_o_t = 5;        % Lagrange multiplier (Shadow price of capital)
r_k_t = 6;        % rental rate of capital
u_t = 7;          % utilization rate
k_t = 8;          % capital stock, k_t+1
c_rt_t = 9;      % consumption of non-ricardian agents
w_t = 10;         % real wage
h_t = 11;         % hours
g_t = 12;         % exogenous gov spending
pi_t = 13;        % inflation
y_t = 14;         % aggregate output
mc_t = 15;        % marginal cost
lambda_p_t = 16;  % price markup shock
mrs_o_t = 17;     % marginal rate of substitution (ricardian)
mrs_rt_t = 18;    % marginal rate of substitution (non-ricardian)
lambda_w_t = 19;  % wage markup shock
gy_t = 20;        % growth rate of output
gc_t = 21;        % growth rate of consumption
gi_t = 22;        % growth rate of investment
gw_t = 23;        % growth rate of wage

Ec_o_t = 24;      % expectational variable
Epi_t = 25;
Ei_t = 26;
Er_k_t = 27;
EQ_o_t = 28;
Ew_t = 29;

eps_a_t = 30;     % exogenous shocks
eps_b_t = 31;
eps_i_t = 32;
eps_r_t = 33;
eps_p_t = 34;
eps_w_t = 35;


c_o_t_f = 36;        
c_t_f = 37;          
R_t_f = 38;          
i_t_f = 39;          
Q_o_t_f = 40;               
r_k_t_f = 41;        
u_t_f = 42;          
k_t_f = 43;          
c_rt_t_f = 44;      
w_t_f = 45;         
h_t_f = 46;                           
y_t_f = 47;       
mrs_o_t_f = 48;     
mrs_rt_t_f = 49;    

Ec_o_t_f = 50;      
Ei_t_f = 51;
Er_k_t_f = 52;
EQ_o_t_f = 53;

omega1_t = 54;

% /** shock indices **/

e_a  = 1;
e_b  = 2;
e_i  = 3;
e_r  = 4;
e_p  = 5;
e_w = 6;
e_g  = 7;
e_v1 = 8;




%=========================================================================
%                          TRANSITION EQUATION
%  
%           s(t) = Phi*s(t-1) + R*e(t)
%           e(t) ~ iid N(0,Se)
% 
%=========================================================================

nep = size(ME,2);

Phi = MY;

[n,n]    = size(Phi);

R   = ME;

Se  = zeros(nep,nep);

Se(e_a,e_a) = sig_a^2;

Se(e_b,e_b) = sig_b^2;

Se(e_i,e_i) = sig_i^2;

Se(e_r,e_r) = sig_r^2;

Se(e_p,e_p) = sig_p^2;

Se(e_w,e_w) = sig_w^2;

Se(e_g,e_g) = sig_g^2;

Se(e_v1,e_v1) = sig_v1^2;

Se(e_p,e_v1) = rho_pv1*(sig_p*sig_v1);

Se(e_v1,e_p) = rho_pv1*(sig_p*sig_v1);


%=========================================================================
%                          MEASUREMENT EQUATION
%  
%           y(t) = a + b*s(t) + u(t) 
%           u(t) ~ N(0,HH)
% 
%=========================================================================

A          = zeros(ny,1);
A(eq_gy,1) = gzstar;
A(eq_gc,1) = gzstar;
A(eq_gi,1) = gzstar;
A(eq_h,1)  = Hss;
A(eq_gw,1) = gzstar;
A(eq_pi,1) = pss100;
A(eq_R,1)  = pss100+rss100;

nstate = size(Phi,2); 

B = zeros(ny,nstate);

B(eq_gy,gy_t) =  1; 

B(eq_gc,gc_t) =  1;
 
B(eq_gi,gi_t) =  1;
 
B(eq_h,h_t)   =  1; 

B(eq_gw,gw_t) =  1; 

B(eq_pi,pi_t) =  1;

B(eq_R,R_t) = 1;

H = zeros(ny,ny);  

end

